<?php

namespace Litecms\Buyadds\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Buyadds\Http\Requests\BuyaddsRequest;
use Litecms\Buyadds\Interfaces\BuyaddsRepositoryInterface;
use Litecms\Buyadds\Models\Buyadds;

/**
 * Resource controller class for buyadds.
 */
class BuyaddsResourceController extends BaseController
{

    /**
     * Initialize buyadds resource controller.
     *
     * @param type BuyaddsRepositoryInterface $buyadds
     *
     * @return null
     */
    public function __construct(BuyaddsRepositoryInterface $buyadds)
    {
        parent::__construct();
        $this->repository = $buyadds;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Buyadds\Repositories\Criteria\BuyaddsResourceCriteria::class);
    }

    /**
     * Display a list of buyadds.
     *
     * @return Response
     */
    public function index(BuyaddsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Buyadds\Repositories\Presenter\BuyaddsPresenter::class)
                ->$function();
        }

        $buyadds = $this->repository->paginate();

        return $this->response->title(trans('buyadds::buyadds.names'))
            ->view('buyadds::buyadds.index', true)
            ->data(compact('buyadds'))
            ->output();
    }

    /**
     * Display buyadds.
     *
     * @param Request $request
     * @param Model   $buyadds
     *
     * @return Response
     */
    public function show(BuyaddsRequest $request, Buyadds $buyadds)
    {

        if ($buyadds->exists) {
            $view = 'buyadds::buyadds.show';
        } else {
            $view = 'buyadds::buyadds.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('buyadds::buyadds.name'))
            ->data(compact('buyadds'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new buyadds.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BuyaddsRequest $request)
    {

        $buyadds = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('buyadds::buyadds.name')) 
            ->view('buyadds::buyadds.create', true) 
            ->data(compact('buyadds'))
            ->output();
    }

    /**
     * Create new buyadds.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BuyaddsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $buyadds                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('buyadds::buyadds.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('buyadds/buyadds/' . $buyadds->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/buyadds/buyadds'))
                ->redirect();
        }

    }

    /**
     * Show buyadds for editing.
     *
     * @param Request $request
     * @param Model   $buyadds
     *
     * @return Response
     */
    public function edit(BuyaddsRequest $request, Buyadds $buyadds)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('buyadds::buyadds.name'))
            ->view('buyadds::buyadds.edit', true)
            ->data(compact('buyadds'))
            ->output();
    }

    /**
     * Update the buyadds.
     *
     * @param Request $request
     * @param Model   $buyadds
     *
     * @return Response
     */
    public function update(BuyaddsRequest $request, Buyadds $buyadds)
    {
        try {
            $attributes = $request->all();

            $buyadds->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('buyadds::buyadds.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('buyadds/buyadds/' . $buyadds->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('buyadds/buyadds/' . $buyadds->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the buyadds.
     *
     * @param Model   $buyadds
     *
     * @return Response
     */
    public function destroy(BuyaddsRequest $request, Buyadds $buyadds)
    {
        try {

            $buyadds->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('buyadds::buyadds.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('buyadds/buyadds/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('buyadds/buyadds/' . $buyadds->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple buyadds.
     *
     * @param Model   $buyadds
     *
     * @return Response
     */
    public function delete(BuyaddsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('buyadds::buyadds.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('buyadds/buyadds'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/buyadds/buyadds'))
                ->redirect();
        }

    }

    /**
     * Restore deleted buyadds.
     *
     * @param Model   $buyadds
     *
     * @return Response
     */
    public function restore(BuyaddsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('buyadds::buyadds.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/buyadds/buyadds'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/buyadds/buyadds/'))
                ->redirect();
        }

    }

}
