<?php

namespace Litecms\Buyadds\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Buyadds\Models\Buyadds;

class BuyaddsPolicy
{

    /**
     * Determine if the given user can view the buyadds.
     *
     * @param UserPolicy $user
     * @param Buyadds $buyadds
     *
     * @return bool
     */
    public function view(UserPolicy $user, Buyadds $buyadds)
    {
        if ($user->canDo('buyadds.buyadds.view') && $user->isAdmin()) {
            return true;
        }

        return $buyadds->user_id == user_id() && $buyadds->user_type == user_type();
    }

    /**
     * Determine if the given user can create a buyadds.
     *
     * @param UserPolicy $user
     * @param Buyadds $buyadds
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('buyadds.buyadds.create');
    }

    /**
     * Determine if the given user can update the given buyadds.
     *
     * @param UserPolicy $user
     * @param Buyadds $buyadds
     *
     * @return bool
     */
    public function update(UserPolicy $user, Buyadds $buyadds)
    {
        if ($user->canDo('buyadds.buyadds.edit') && $user->isAdmin()) {
            return true;
        }

        return $buyadds->user_id == user_id() && $buyadds->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given buyadds.
     *
     * @param UserPolicy $user
     * @param Buyadds $buyadds
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Buyadds $buyadds)
    {
        return $buyadds->user_id == user_id() && $buyadds->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given buyadds.
     *
     * @param UserPolicy $user
     * @param Buyadds $buyadds
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Buyadds $buyadds)
    {
        if ($user->canDo('buyadds.buyadds.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given buyadds.
     *
     * @param UserPolicy $user
     * @param Buyadds $buyadds
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Buyadds $buyadds)
    {
        if ($user->canDo('buyadds.buyadds.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
