<?php

namespace Litecms\Buyadds\Providers;

use Illuminate\Support\ServiceProvider;

class BuyaddsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'buyadds');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'buyadds');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.buyadds', function ($app) {
            return $this->app->make('Litecms\Buyadds\Buyadds');
        });

                // Bind Buyadds to repository
        $this->app->bind(
            'Litecms\Buyadds\Interfaces\BuyaddsRepositoryInterface',
            \Litecms\Buyadds\Repositories\Eloquent\BuyaddsRepository::class
        );

        $this->app->register(\Litecms\Buyadds\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Buyadds\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.buyadds'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/buyadds.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/buyadds')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/buyadds')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
